@@ -3,11 +3,13 @@ import zipfile
 
 from ..objects.exceptions import JobsException
 from ..utils.generate_query_str import generate_query_str
+from galileo_sdk.compat import quote
 
 
 class JobsService:
-    def __init__(self, jobs_repo):
+    def __init__(self, jobs_repo, profile_repo):
         self._jobs_repo = jobs_repo
+        self._profile_repo = profile_repo
 
     def request_send_job(self):
         r = self._jobs_repo.request_send_job()
@@ -56,7 +58,18 @@ class JobsService:
         statuses=None,
         page=1,
         items=25,
+        projectids=None,
+        archived=False,
+        receiver_archived=False,
+        partial_names=None,
+        lz=None,
+        ownerids=None,
+        sort_by=None,
+        sort_order=None,
     ):
+        if userids is None:
+            self_profile = self._profile_repo.self()
+            userids = [self_profile.userid]
         query = generate_query_str(
             {
                 "page": page,
@@ -67,12 +80,20 @@ class JobsService:
                 "userids": userids,
                 "stationids": stationids,
                 "statuses": statuses,
+                "projectids": projectids,
+                "archived": archived,
+                "receiver_archived": receiver_archived,
+                "partial_names": partial_names,
+                "machines": lz,
+                "ownerids": ownerids,
+                "sort_by": sort_by,
+                "sort_order": sort_order,
             },
         )
         return self._jobs_repo.list_jobs(query)
 
-    def download_job_results(self, job_id, path):
-        files = self._jobs_repo.get_results_url(job_id)
+    def download_job_results(self, job_id, path, nonce=None):
+        files = self._jobs_repo.get_results_metadata(job_id)
 
         if not files:
             raise JobsException(job_id, "No files to download")
@@ -83,15 +104,21 @@ class JobsService:
             absolute_path = os.path.join(path, file.filename)
             self._jobs_repo.download_results(
                 job_id,
-                generate_query_str({"filename": file.filename, "path": file.path}),
+                generate_query_str(
+                    {
+                        "filename": quote(file.filename, safe=""),
+                        "path": file.path,
+                        "nonce": nonce,
+                    }
+                ),
                 os.path.join(path, file.filename),
             )
             files_downloaded.append(absolute_path)
 
         return files_downloaded
 
-    def download_and_extract_job_results(self, job_id, path):
-        files_downloaded = self.download_job_results(job_id, path)
+    def download_and_extract_job_results(self, job_id, path, nonce=None):
+        files_downloaded = self.download_job_results(job_id, path, nonce)
         for file in files_downloaded:
             dir = file.rsplit(".zip", 1)[0]
             if not os.path.exists(dir):
