@@ -1,7 +1,13 @@
-class JobsSdk:
-    def __init__(self, jobs_service, events=None):
+from .event import EventsSdk
+from ..business.objects.jobs import UpdateJobRequest
+
+
+class JobsSdk(EventsSdk):
+    def __init__(self, jobs_service, connector=None, events=None):
         self._jobs_service = jobs_service
-        self._events = events
+        super(JobsSdk, self).__init__(
+            connector=connector, events=events,
+        )
 
     def on_job_launcher_updated(self, func):
         """
@@ -10,6 +16,7 @@ class JobsSdk:
         :param func: Callable[[JobLauncherUpdatedEvent], None]
         :return: None
         """
+        self._set_event_handler("jobs")
         self._events.on_job_launcher_updated(func)
 
     def on_job_launcher_submitted(self, func):
@@ -18,6 +25,7 @@ class JobsSdk:
         :param func: Callable[[JobLauncherSubmittedEvent]
         :return: None
         """
+        self._set_event_handler("jobs")
         self._events.on_job_launcher_submitted(func)
 
     def on_station_job_updated(self, func):
@@ -27,6 +35,7 @@ class JobsSdk:
         :param func: Callable[[StationJobUpdatedEvent], None]
         :return: None
         """
+        self._set_event_handler("jobs")
         self._events.on_station_job_updated(func)
 
     def request_stop_job(self, job_id):
@@ -84,11 +93,17 @@ class JobsSdk:
         statuses=None,
         page=1,
         items=25,
-        projectids=None
+        projectids=None,
+        archived=False,
+        receiver_archived=False,
+        partial_names=None,
+        machines=None,
+        ownerids=None,
+        sort_by=None,
+        sort_order=None,
     ):
         """
         List of your jobs
-
         :param jobids: List[str]: Filter by job ids
         :param receiverids: List[str]: Filter by receiver ids
         :param oaids: List[str]: Filter by offer acceptance ids
@@ -97,6 +112,14 @@ class JobsSdk:
         :param statuses: List[str]: Filter by statuses
         :param page: int: Filter by page
         :param items: int: Filter by items
+        :param projectids: List[str]: Filter by projectid
+        :param archived: boolean: Filter by archived
+        :param receiver_archived: boolean: Filter by receiver archived
+        :param partial_names: List[str]: Filter by partial names
+        :param machines: List[str]: Filter by machines id
+        :param ownerids: List[str]: Filter by ownerid
+        :param sort_by: EJobSort
+        :param sort_order: str: "asc" or "desc"
         :return: List[Job]
         """
         return self._jobs_service.list_jobs(
@@ -108,7 +131,14 @@ class JobsSdk:
             statuses=statuses,
             page=page,
             items=items,
-            projectids=projectids
+            projectids=projectids,
+            archived=archived,
+            receiver_archived=receiver_archived,
+            partial_names=partial_names,
+            lz=machines,
+            ownerids=ownerids,
+            sort_by=sort_by,
+            sort_order=sort_order,
         )
 
     def download_job_results(self, job_id, path, nonce=None):
@@ -122,12 +152,14 @@ class JobsSdk:
         """
         return self._jobs_service.download_job_results(job_id, path, nonce)
 
-    def update_job(self, request):
+    def update_job(self, job_id, archived=None):
         """ Updates an existing job
 
-        :param request: UpdateJobRequest
+        :param job_id:
+        :param archived: bool: Archive a job
         return: Job
         """
+        request = UpdateJobRequest(job_id, archived)
 
         return self._jobs_service.update_job(request)
 
@@ -140,5 +172,13 @@ class JobsSdk:
         """
         return self._jobs_service.request_kill_job(job_id)
 
-    def download_and_extract_job_results(self, job_id, path):
-        return self._jobs_service.download_and_extract_job_results(job_id, path)
+    def download_and_extract_job_results(self, job_id, path, nonce=None):
+        """
+        Download and extract your job results when job is completed
+
+        :param job_id: str
+        :param path: str: path to directory, where results will be saved
+        :param nonce: str: can still download the file if provide an auth token
+        :return: List[str]: list of filenames that were downloaded
+        """
+        return self._jobs_service.download_and_extract_job_results(job_id, path, nonce)
